@@ -4,9 +4,9 @@ package Class::Trait::Reflection;
 use strict;
 use warnings;
 
-our $VERSION  = '0.04';
+our $VERSION  = '0.05';
 
-use Class::Trait;
+use Class::Trait ();
 
 use Data::Dumper ();
 
@@ -233,7 +233,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 by Infinity Interactive, Inc.
+Copyright 2004, 2005 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com> 
 
